@@ -18,7 +18,7 @@ from jdatetime.jalali import (
     GregorianToJalali, JalaliToGregorian, j_days_in_month,
 )
 
-__VERSION__ = "4.0.0"
+__VERSION__ = "4.1.0"
 MINYEAR = 1
 MAXYEAR = 9377
 
@@ -186,11 +186,11 @@ class date:
     ]
     j_weekdays_fa = [
         'شنبه',
-        'یکشنبه',
+        'یک‌شنبه',
         'دوشنبه',
-        'سه شنبه',
+        'سه‌شنبه',
         'چهارشنبه',
-        'پنجشنبه',
+        'پنج‌شنبه',
         'جمعه',
     ]
     j_ampm_fa = {'PM': 'بعد از ظهر', 'AM': 'قبل از ظهر'}
@@ -348,6 +348,18 @@ class date:
         (y, m, d) = GregorianToJalali(d.year, d.month, d.day).getJalaliList()
         return date(y, m, d)
 
+    @staticmethod
+    def j_month_to_num(month_name):
+        return date.j_months_en.index(month_name.lower().capitalize()) + 1
+
+    @staticmethod
+    def j_month_short_to_num(month_name):
+        return date.j_months_short_en.index(month_name.lower().capitalize()) + 1
+
+    @staticmethod
+    def j_month_fa_to_num(month_name):
+        return date.j_months_fa.index(month_name) + 1
+
     def __repr__(self):
         return f"jdatetime.date({self.year}, {self.month}, {self.day})"
 
@@ -636,17 +648,19 @@ date.min = date(MINYEAR, 1, 1)
 date.max = date(MAXYEAR, 12, 30)
 
 _DIRECTIVE_PATTERNS = {
-    '%Y': '(?P<Y>[0-9]{4})',
-    '%y': '(?P<y>[0-9]{2})',
-    '%m': '(?P<m>[0-9]{1,2})',
-    '%d': '(?P<d>[0-9]{1,2})',
-    '%H': '(?P<H>[0-9]{1,2})',
-    '%M': '(?P<M>[0-9]{1,2})',
-    '%S': '(?P<S>[0-9]{1,2})',
-    '%f': '(?P<f>[0-9]{1,6})',
+    '%Y': '(?P<Y>\d{4})',
+    '%y': '(?P<y>\d{2})',
+    '%m': '(?P<m>\d{1,2})',
+    '%d': '(?P<d>\d{1,2})',
+    '%H': '(?P<H>\d{1,2})',
+    '%M': '(?P<M>\d{1,2})',
+    '%S': '(?P<S>\d{1,2})',
+    '%f': '(?P<f>\d{1,6})',
+    '%B': '(?P<B>[a-zA-Z\u0600-\u06EF\uFB8A\u067E\u0686\u06AF]{3,12})',
+    '%b': '(?P<b>[a-zA-Z]{3})',
+    '%z': '(?P<z>[+-]\d\d:?[0-5\u06F0-\u06F5]\d(:?[0-5\u06F0-\u06F5]\d(\.\d{1,6})?)?)',
 }
 
-
 # Replace directives with patterns according to _DIRECTIVE_PATTERNS
 _directives_to_pattern = _partial(
     re.compile('|'.join(_DIRECTIVE_PATTERNS)).sub,
@@ -914,14 +928,33 @@ class datetime(date):
         year = int(get('Y') or get('y') or 1279)
         if year < 100:  # %y, see the discussion at #100
             year += 1400 if year <= 68 else 1300
+        month = get('B') or get('b') or int(get('m', 1))
+        if isinstance(month, str):
+            try:
+                if get('b'):
+                    month = date.j_month_short_to_num(month_name=month)
+                elif month.isascii():
+                    month = date.j_month_to_num(month_name=month)
+                else:
+                    month = date.j_month_fa_to_num(month_name=month)
+            except ValueError:
+                raise ValueError(
+                    "time data '%s' does not match format '%s'" %
+                    (date_string, format)
+                )
+
+        timezone_string = get('z', None)
+        timezone = datetime._timezone_from_string(timezone_string)
+
         return datetime(
             year,
-            int(get('m', 1)),
+            month,
             int(get('d', 1)),
             int(get('H', 0)),
             int(get('M', 0)),
             int(get('S', 0)),
             None if get('f') is None else int('{:0<6}'.format(get('f'))),
+            timezone,
         )
 
     def replace(
@@ -1290,3 +1323,29 @@ class datetime(date):
             tzinfo=self.tzinfo,
             locale=locale,
         )
+
+    @staticmethod
+    def _timezone_from_string(timezone_string):
+        if timezone_string is None:
+            return None
+        z = timezone_string  # keep the original string for value error exception.
+        if z[3] == ':':
+            z = z[:3] + z[4:]
+            if len(z) > 5:
+                if z[5] != ':':
+                    msg = f"Inconsistent use of : in {timezone_string}"
+                    raise ValueError(msg)
+                z = z[:5] + z[6:]
+        hours = int(z[1:3])
+        minutes = int(z[3:5])
+        seconds = int(z[5:7] or 0)
+        gmtoff = (hours * 60 * 60) + (minutes * 60) + seconds
+        gmtoff_remainder = z[8:]
+        # Pad to always return microseconds.
+        gmtoff_remainder_padding = "0" * (6 - len(gmtoff_remainder))
+        gmtoff_fraction = int(gmtoff_remainder + gmtoff_remainder_padding)
+        if z.startswith("-"):
+            gmtoff = -gmtoff
+            gmtoff_fraction = -gmtoff_fraction
+        timezone = py_datetime.timezone(timedelta(seconds=gmtoff, microseconds=gmtoff_fraction))
+        return timezone
